﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class DeleteFleetErrorCode { NOT_SET, fleetIdDoesNotExist, fleetIdMalformed, fleetNotInDeletableState, unexpectedError };

namespace DeleteFleetErrorCodeMapper {
AWS_EC2_API DeleteFleetErrorCode GetDeleteFleetErrorCodeForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForDeleteFleetErrorCode(DeleteFleetErrorCode value);
}  // namespace DeleteFleetErrorCodeMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
